import numpy as np

class BetaPlaneMap:
    def __init__(self, scale, xc, yc, f0, beta, y0=0.):
        """
        scale : map factor from reference mesh (on disk) to physical mesh
        xc, yc : position in physical space of point (0,0) of the reference mesh
        y0 : physical position at which f=f0 : f = f0 + beta*(y-y0) """
        self.scale, self.xc, self.yc = scale, xc, yc
        self.f0, self.beta, self.y0 = f0, beta, y0
    def coriolis(self, x,y): 
        """x,y are coordinates in the physical domain."""
        return self.f0 + self.beta*(y-self.y0)
    def map(self, x, y):
        """x,y are coordinates in the reference domain."""
        return self.xc + self.scale*x, self.yc + self.scale*y 
    def map_factor(self, lon,lat): return 0.*lon + self.scale

class SphereMap:
    def __init__(self, radius, Omega):
        """
        radius : planetary radius
        Omega : rotation rate => f = 2*Omega*sin(lat)"""
        self.radius, self.Omega = radius, Omega
    def coriolis(self, lon,lat):
       return 2.*self.Omega*np.sin(lat)
    def map(self, lon,lat): return lon, lat
    def map_factor(self, lon,lat): return 0.*lon + self.radius

# https://en.wikipedia.org/wiki/Mercator_projection
